@@ -5,6 +5,7 @@ from pytorch_optimizer.adamp import AdamP
 from pytorch_optimizer.diffgrad import DiffGrad
 from pytorch_optimizer.diffrgrad import DiffRGrad
 from pytorch_optimizer.fp16 import SafeFP16Optimizer
+from pytorch_optimizer.lamb import Lamb
 from pytorch_optimizer.madgrad import MADGRAD
 from pytorch_optimizer.radam import RAdam
 from pytorch_optimizer.ranger import Ranger
@@ -39,6 +40,8 @@ def load_optimizers(optimizer: str, use_fp16: bool = False):
         opt = DiffGrad
     elif optimizer == 'adahessian':
         opt = AdaHessian
+    elif optimizer == 'lamb':
+        opt = Lamb
     else:
         raise NotImplementedError(f'[-] not implemented optimizer : {optimizer}')
 
